@@ -343,6 +343,7 @@ _dbus_server_new_for_socket (int              *fds,
 
   SERVER_UNLOCK (server);
 
+  _dbus_server_trace_ref (&socket_server->base, 0, 1, "new_for_socket");
   return (DBusServer*) socket_server;
 
  failed_2:
@@ -477,7 +478,10 @@ _dbus_server_new_for_tcp_socket (const char     *host,
   if (server == NULL)
     {
       dbus_set_error (error, DBUS_ERROR_NO_MEMORY, NULL);
-      goto failed_4;
+      if (noncefile != NULL)
+        goto failed_4;
+      else
+        goto failed_2;
     }
 
   _dbus_string_free (&port_str);
